@@ -1,19 +1,20 @@
 import sys
 
+
 def print_info() -> None:
     print(
-        "Type annotations for boto3.STS 1.17.58\n"
-        "Version:         1.17.58.0\n"
-        "Builder version: 4.6.0\n"
+        "Type annotations for boto3.STS 1.17.70\n"
+        "Version:         1.17.70\n"
+        "Builder version: 4.11.1\n"
         "Docs:            https://pypi.org/project/mypy-boto3-sts/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.58.0")
+    print("1.17.70")
 
 
 def main() -> None:
