@@ -1,5 +1,7 @@
 """
-Main interface for sts service client
+Type annotations for sts service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
 
 Usage::
 
@@ -52,7 +54,8 @@ class Exceptions:
 
 class STSClient:
     """
-    [STS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
     """
 
     meta: ClientMeta
@@ -73,7 +76,8 @@ class STSClient:
         SourceIdentity: str = None,
     ) -> AssumeRoleResponseTypeDef:
         """
-        [Client.assume_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.assume_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.assume_role)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume-role)
         """
 
     def assume_role_with_saml(
@@ -86,7 +90,8 @@ class STSClient:
         DurationSeconds: int = None,
     ) -> AssumeRoleWithSAMLResponseTypeDef:
         """
-        [Client.assume_role_with_saml documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume-role-with-saml)
         """
 
     def assume_role_with_web_identity(
@@ -100,19 +105,22 @@ class STSClient:
         DurationSeconds: int = None,
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
         """
-        [Client.assume_role_with_web_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume-role-with-web-identity)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#can-paginate)
         """
 
     def decode_authorization_message(
         self, EncodedMessage: str
     ) -> DecodeAuthorizationMessageResponseTypeDef:
         """
-        [Client.decode_authorization_message documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#decode-authorization-message)
         """
 
     def generate_presigned_url(
@@ -123,17 +131,20 @@ class STSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#generate-presigned-url)
         """
 
     def get_access_key_info(self, AccessKeyId: str) -> GetAccessKeyInfoResponseTypeDef:
         """
-        [Client.get_access_key_info documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get-access-key-info)
         """
 
     def get_caller_identity(self) -> GetCallerIdentityResponseTypeDef:
         """
-        [Client.get_caller_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get-caller-identity)
         """
 
     def get_federation_token(
@@ -145,12 +156,14 @@ class STSClient:
         Tags: List[TagTypeDef] = None,
     ) -> GetFederationTokenResponseTypeDef:
         """
-        [Client.get_federation_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.get_federation_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.get_federation_token)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get-federation-token)
         """
 
     def get_session_token(
         self, DurationSeconds: int = None, SerialNumber: str = None, TokenCode: str = None
     ) -> GetSessionTokenResponseTypeDef:
         """
-        [Client.get_session_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/sts.html#STS.Client.get_session_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.get_session_token)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get-session-token)
         """
